"""
Geometrical transformations
==============================
This examples demos some simple geometrical transformations on a face image.
Code modified from examples found at:
http://www.scipy-lectures.org/advanced/image_processing/
"""

import numpy as np
import scipy.misc as misc
from scipy import ndimage
import matplotlib.pyplot as plt


face = misc.imread('FabioInGray.jpg')

lx, ly = face.shape
# Cropping (half way through the image)
crop_face = face[lx/4:-lx/4, ly/4:-ly/4]
# up <-> down flip
flip_ud_face = np.flipud(face)
# rotation by 45 degrees with reshaping
rotate_face = ndimage.rotate(face, 45)
# rotation by 45 degrees without reshaping
rotate_face_noreshape = ndimage.rotate(face, 45, reshape=False)

plt.figure(figsize=(12.5, 2.5))

plt.subplot(151)
plt.imshow(face, cmap=plt.cm.gray)
plt.axis('off')
plt.subplot(152)
plt.imshow(crop_face, cmap=plt.cm.gray)
plt.axis('off')
plt.subplot(153)
plt.imshow(flip_ud_face, cmap=plt.cm.gray)
plt.axis('off')
plt.subplot(154)
plt.imshow(rotate_face, cmap=plt.cm.gray)
plt.axis('off')
plt.subplot(155)
plt.imshow(rotate_face_noreshape, cmap=plt.cm.gray)
plt.axis('off')

plt.subplots_adjust(wspace=0.02, hspace=0.3, top=1, bottom=0.1, left=0,
                    right=1)

plt.show()
